<?php
namespace Drupal\cleantalk\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\cleantalk\CleantalkSFW;
use Drupal\cleantalk\CleantalkHelper;

class CleantalkSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cleantalk_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('cleantalk.settings');

    foreach ($form_state->getValues() as $key=>$value) {
      if (strpos($key, 'cleantalk') !== FALSE)
        $config->set($key, $value);
    }
    $config->save();

    if (method_exists($this, '_submitForm')) {
      $this->_submitForm($form, $form_state);
    }
    if(isset($_POST['cleantalk_authkey'])){
      CleantalkHelper::api_method_send_empty_feedback($_POST['cleantalk_authkey'], CLEANTALK_USER_AGENT);
    }
    if(isset($_POST['cleantalk_authkey']) && isset($_POST['cleantalk_sfw']) && $_POST['cleantalk_sfw'] == 1){
      $sfw = new CleantalkSFW();
      $sfw->sfw_update($_POST['cleantalk_authkey']);
      $sfw->send_logs($_POST['cleantalk_authkey']);
    }
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['cleantalk.settings'];
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {
    // @FIXME
    // Could not extract the default value because it is either indeterminate, or
    // not scalar. You'll need to provide a default value in
    // config/install/cleantalk.settings.yml and config/schema/cleantalk.schema.yml.

    $form['cleantalk_authkey'] = [
      '#type' => 'textfield',
      '#title' => t('Access key'),
      '#size' => 20,
      '#maxlength' => 20,
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_authkey') ? \Drupal::config('cleantalk.settings')->get('cleantalk_authkey') : '',
      '#description' => t('Click <a target="_blank" href="http://cleantalk.org/register?platform=drupal">here</a> to get access key.'),
    ];
    $form['cleantalk_comments'] = array(
      '#type' => 'fieldset',
      '#title' => t('Comments'),
    );
    $form['cleantalk_comments']['cleantalk_check_comments'] = array(
    '#type' => 'checkbox',
    '#title' => t('Check comments'),
    '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_comments'),
    '#description' => t('Enabling this option will allow you to check all comments on your website.'),   
    ); 
    $form['cleantalk_comments']['cleantalk_check_comments_automod'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable automoderation'),
    '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_comments_automod'),
    '#description' => t('Automatically put suspicious comments which may not be 100% spam to manual approvement and block obvious spam comments.').
    '<br /><span class="admin-missing">' .
    t('Note: If disabled, all suspicious comments will be automatically blocked!') .
    '</span>', 
    '#states' => array(
        // Only show this field when the value when checking comments is enabled
        'disabled' => array(
            ':input[name="cleantalk_check_comments"]' => array('checked' => FALSE),
        ),
      ),          
    ); 
    $form['cleantalk_comments']['cleantalk_check_comments_min_approved'] = array(
      '#type' => 'textfield',
      '#title' => t('Minimum approved comments per registered user'),
      '#size' => 5,
      '#maxlength' => 5,
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_comments_min_approved'),
      '#element_validate' => array('element_validate_integer_positive'),
      '#description' => t('Moderate messages of guests and registered users who have approved messages less than this value (must be more than 0).'),
      '#states' => array(
          // Only show this field when the value when checking comments is enabled
          'disabled' => array(
              ':input[name="cleantalk_check_comments"]' => array('checked' => FALSE),
          ),
      ),    
    );    
    $form['cleantalk_check_register'] = array(
      '#type' => 'checkbox',
      '#title' => t('Check registrations'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_register'),
      '#description' => t('Enabling this option will allow you to check all registrations on your website.'),
    );


    $form['cleantalk_check_webforms'] = array(
      '#type' => 'checkbox',
      '#title' => t('Check webforms'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_webforms'),
      '#description' => t('Enabling this option will allow you to check all webforms on your website.'),
    );

    $form['cleantalk_check_contact_forms'] = array(
      '#type' => 'checkbox',
      '#title' => t('Check contact forms'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_contact_forms'),
      '#description' => t('Enabling this option will allow you to check all contact forms on your website.'),
    );
    $form['cleantalk_check_forum_topics'] = array(
      '#type' => 'checkbox',
      '#title' => t('Check forum topics'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_forum_topics'),
      '#description' => t('Enabling this option will allow you to check all forum topics on your website.'),
    );    
    $form['cleantalk_check_ccf'] = array(
    '#type' => 'checkbox',
    '#title' => t('Check custom forms'),
    '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_check_ccf'),
    '#description' => t('Enabling this option will allow you to check all forms on your website.') .
    '<br /><span class="admin-missing">' .
    t('Note: May cause conflicts!') .
    '</span>',
    );
    $form['cleantalk_sfw'] = [
      '#type' => 'checkbox',
      '#title' => t('SpamFireWall'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_sfw'),
      '#description' => t('This option allows to filter spam bots before they access website. Also reduces CPU usage on hosting server and accelerates pages load time.'),
    ];    
    $form['cleantalk_link'] = [
      '#type' => 'checkbox',
      '#title' => t('Tell others about CleanTalk'),
      '#default_value' => \Drupal::config('cleantalk.settings')->get('cleantalk_link'),
      '#description' => t('Checking this box places a small link under the comment form that lets others know what anti-spam tool protects your site.'),
    ];

    return parent::buildForm($form, $form_state);
  }

}
